@@ -84,11 +84,11 @@ class PyXploraApi(PyXplora):
     def version(self) -> str:
         return "{0}-{1}".format(VERSION, VERSION_APP)
 
-    async def setDevices(self) -> List[Dict[str, Any]]:
-        return await self._setDevices()
+    async def setDevices(self, ids: list = []) -> List[Dict[str, Any]]:
+        return await self._setDevices(ids)
 
-    async def _setDevices(self) -> List[str]:
-        wuids: List[str] = self.getWatchUserIDs()
+    async def _setDevices(self, ids: list = []) -> List[str]:
+        wuids: List[str] = self.getWatchUserIDs(ids)
         for wuid in wuids:
             self.device[wuid] = {}
             self.device[wuid]["getWatchAlarm"] = await create_task(self.getWatchAlarm(wuid=wuid))
